/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";

package android.os.statsd.automotive.car;

import "frameworks/proto_logging/stats/atoms.proto";
import "frameworks/proto_logging/stats/atom_field_options.proto";

option java_package = "com.android.os.car";
option java_multiple_files = true;

extend Atom {
    optional CarWakeupFromSuspendReported car_wakeup_from_suspend_reported = 852 [(module) = "car"];
}

/**
 * Logs when a wakeup from suspend event occurs.
 *
 * Logged from package: packages/services/Car/service
 */
message CarWakeupFromSuspendReported {
  enum ResumeType {
    UNSPECIFIED = 0;
    RAM = 1;
    DISK = 2;
  }
  optional ResumeType resume_type = 1;
  optional int64 kernel_start_wall_time_millis = 2;
  optional int64 car_service_start_wall_time_millis = 3;
  optional int64 user_perceived_start_wall_time_millis = 4;
  optional int64 device_start_wall_time_millis = 5;
}
